@@ -109,7 +109,7 @@ mod tests {
 
         assert!(statement.forex_trades.is_empty());
         assert!(!statement.stock_buys.is_empty());
-        assert_eq!(statement.stock_sells.is_empty(), name == "my");
+        assert!(!statement.stock_sells.is_empty());
         assert!(statement.dividends.is_empty());
 
         assert!(!statement.open_positions.is_empty());
